@@ -94,12 +94,10 @@ dg_shpfname_south_africa <- function(){
 #'                  functions
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #'
 #' dggs <- dgconstruct(area=5,metric=FALSE)
-#' }
 #' @export 
 dgconstruct <- function(
   projection   = 'ISEA',
@@ -170,11 +168,9 @@ dgconstruct <- function(
 #'             functions
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dggs <- dgsetres(dggs,10)
-#' }
 #' @export 
 dgsetres <- function(dggs,res){
   dggs[['res']] = res
@@ -196,11 +192,9 @@ dgsetres <- function(dggs,res){
 #' @return     The function has no return value. A stop signal is raised if the
 #'             object is misspecified
 #' @examples
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dgverify(dggs)
-#' }
 #' @export
 dgverify <- function(dggs){
   #See page 21 of documentation for further bounds
@@ -248,14 +242,12 @@ dgverify <- function(dggs){
 #'             in the discrete grid.
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' data(dgquakes)
 #'
 #' #Construct a grid with cells about ~1000 miles wide
 #' dggs          <- dgconstruct(spacing=1000,metric=FALSE) 
 #' dgquakes$cell <- dgtransform(dggs,dgquakes$lat,dgquakes$lon)
-#' }
 #' @export 
 dgtransform <- function(dggs, lat, lon){ #TODO: Make sure we're not modifying the original dggs
   dgverify(dggs)
@@ -280,24 +272,22 @@ dgtransform <- function(dggs, lat, lon){ #TODO: Make sure we're not modifying th
 #' @return No return. All info is printed to the screen.
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dginfo(dggs)
-#' }
 #' @export 
 dginfo <- function(dggs){
   dgverify(dggs)
 
   res <- dggetres(dggs)
 
-  scipen <- getOption('scipen')
+  oops <- options()
+  on.exit(options(oops))
+
   options(scipen=999)
 
   print(res, sep="\r\n")
 
-  options(scipen=scipen)
-
   NULL
 }
 
@@ -317,11 +307,9 @@ dginfo <- function(dggs){
 #'             scale of the cells. All values are in kilometres.
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dggetres(dggs)
-#' }
 #' @export 
 dggetres <- function(dggs){
   dgverify(dggs)
@@ -355,7 +343,6 @@ dggetres <- function(dggs){
 #' @return     The maximum cell id.
 #'
 #' @examples 
-#' \dontrun{
 #' #Choose a set of cells randomly distributed over the Earth
 #' library(dggridR)
 #' dggs    <- dgconstruct(spacing=1000, metric=FALSE, resround='down')
@@ -363,7 +350,6 @@ dggetres <- function(dggs){
 #' maxcell <- dgmaxcell(dggs)                     #Get maximum cell id
 #' cells   <- sample(1:maxcell, N, replace=FALSE) #Choose random cells
 #' grid    <- dgcellstogrid(dggs,cells,frame=TRUE,wrapcells=TRUE) #Get grid
-#' }
 #' @export 
 dgmaxcell <- function(dggs,res=NA){
   dgverify(dggs)
@@ -393,7 +379,7 @@ dgmaxcell <- function(dggs,res=NA){
 #' @param dggs      A dggs object from dgconstruct()
 #'
 #' @param col       Column in which to search for a close value. Should be: 
-#'                  AreaKm, SpacingKm, or CLSKm.
+#'                  area_km, spacing_km, or cls_km.
 #'
 #' @param val       The value to search for
 #'
@@ -407,12 +393,11 @@ dgmaxcell <- function(dggs,res=NA){
 #' @return A number representing the grid resolution
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
-#' res  <- dg_closest_res(dggs,'AreaKm',1)
+#' res  <- dg_closest_res(dggs,'area_km',1)
 #' dggs <- dgsetres(dggs,res)
-#' }
+#' @export
 dg_closest_res <- function(dggs,col,val,round='nearest',show_info=TRUE,metric=TRUE){
   KM_TO_M <- 0.621371
 
@@ -420,6 +405,9 @@ dg_closest_res <- function(dggs,col,val,round='nearest',show_info=TRUE,metric=TR
 
   ret <- dggetres(dggs)
 
+  if(!(col %in% c('area_km', 'spacing_km', 'cls_km')))
+    stop("'col' must be one of area_km, spacing_km, or cls_km")
+
   searchvec = ret[col]
 
   if(!metric)
@@ -468,12 +456,10 @@ dg_closest_res <- function(dggs,col,val,round='nearest',show_info=TRUE,metric=TR
 #' @return A number representing the grid resolution
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_area(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#' }
 #' @export 
 dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'area_km',area,round,show_info,metric)
@@ -502,12 +488,10 @@ dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metr
 #' @return A number representing the grid resolution
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_spacing(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#' }
 #' @export 
 dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'spacing_km',spacing,round,show_info,metric)
@@ -538,12 +522,10 @@ dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRU
 #' @return A number representing the grid resolution
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_cls(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#' }
 #' @export
 dg_closest_res_to_cls <- function(dggs,cls,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'cls_km',cls,round,show_info,metric)
@@ -652,7 +634,6 @@ dg_process_polydata <- function(polydata,frame,wrapcells){
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(spacing=1000,metric=FALSE,resround='down')
 #'
@@ -660,7 +641,6 @@ dg_process_polydata <- function(polydata,frame,wrapcells){
 #' grid <- dgrectgrid(dggs,
 #'                minlat=24.7433195, minlon=-124.7844079, 
 #'                maxlat=49.3457868, maxlon=-66.9513812, frame=TRUE)
-#' }
 #' @export
 dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
@@ -709,7 +689,7 @@ dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
-#' \dontrun{
+#' \donttest{
 #' library(dggridR)
 #' dggs         <- dgconstruct(res=20)
 #' res          <- dg_closest_res_to_spacing(dggs,spacing=1000,round='down',metric=FALSE)
@@ -762,7 +742,6 @@ dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Dens
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #' data(dgquakes)
 #'
@@ -772,7 +751,6 @@ dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Dens
 #'
 #' #Get grid cells for the earthquakes identified
 #' grid          <- dgcellstogrid(dggs, dgquakes$cell, frame=TRUE)
-#' }
 #' @export
 dgcellstogrid <- function(dggs,cells,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
@@ -864,12 +842,10 @@ dgsavegrid <- function(grid,shpfname) {
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
-#' \dontrun{
 #' library(dggridR)
 #'
 #' dggs <- dgconstruct(spacing=25, metric=FALSE, resround='nearest')
 #' south_africa_grid <- dgshptogrid(dggs,dg_shpfname_south_africa())
-#' }
 #' @export
 dgshptogrid <- function(dggs,shpfname,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
